pub struct AgentManifest {
pub agent_id: String,
pub title: String,
pub description: String,
pub supported_modes: Vec<String>,
pub input_content_types: Vec<String>,
pub output_content_types: Vec<String>,
pub metadata: HashMap<String, String>,
pub transport_endpoints: Vec<TransportEndpoint>,
}Fields
agent_id: Stringtitle: Stringdescription: Stringsupported_modes: Vec<String>input_content_types: Vec<String>output_content_types: Vec<String>metadata: HashMap<String, String>transport_endpoints: Vec<TransportEndpoint>Trait Implementations
Sourceimpl Clone for AgentManifest
impl Clone for AgentManifest
Sourcefn clone(&self) -> AgentManifest
fn clone(&self) -> AgentManifest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentManifest
impl Debug for AgentManifest
Sourceimpl Default for AgentManifest
impl Default for AgentManifest
Sourcefn default() -> AgentManifest
fn default() -> AgentManifest
Returns the “default value” for a type. Read more
Sourceimpl Message for AgentManifest
impl Message for AgentManifest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AgentManifest
impl PartialEq for AgentManifest
Sourcefn eq(&self, other: &AgentManifest) -> bool
fn eq(&self, other: &AgentManifest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for AgentManifest