pub struct Capabilities {
pub sessions: Option<SessionsCapability>,
pub cancellation: Option<CancellationCapability>,
pub progress: Option<ProgressCapability>,
pub manifest: Option<ManifestCapability>,
pub mode_registry: Option<ModeRegistryCapability>,
pub roots: Option<RootsCapability>,
pub policy_registry: Option<PolicyRegistryCapability>,
pub experimental: Option<ExperimentalCapabilities>,
}Fields
sessions: Option<SessionsCapability>cancellation: Option<CancellationCapability>progress: Option<ProgressCapability>manifest: Option<ManifestCapability>mode_registry: Option<ModeRegistryCapability>roots: Option<RootsCapability>policy_registry: Option<PolicyRegistryCapability>experimental: Option<ExperimentalCapabilities>Trait Implementations
Sourceimpl Clone for Capabilities
impl Clone for Capabilities
Sourcefn clone(&self) -> Capabilities
fn clone(&self) -> Capabilities
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Capabilities
impl Debug for Capabilities
Sourceimpl Default for Capabilities
impl Default for Capabilities
Sourcefn default() -> Capabilities
fn default() -> Capabilities
Returns the “default value” for a type. Read more
Sourceimpl Message for Capabilities
impl Message for Capabilities
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for Capabilities
impl PartialEq for Capabilities
impl StructuralPartialEq for Capabilities