pub struct ModeDescriptor {
pub mode: String,
pub mode_version: String,
pub title: String,
pub description: String,
pub determinism_class: String,
pub participant_model: String,
pub message_types: Vec<String>,
pub terminal_message_types: Vec<String>,
pub schema_uris: HashMap<String, String>,
}Fields
mode: Stringmode_version: Stringtitle: Stringdescription: Stringdeterminism_class: Stringparticipant_model: Stringmessage_types: Vec<String>terminal_message_types: Vec<String>schema_uris: HashMap<String, String>Trait Implementations
Sourceimpl Clone for ModeDescriptor
impl Clone for ModeDescriptor
Sourcefn clone(&self) -> ModeDescriptor
fn clone(&self) -> ModeDescriptor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModeDescriptor
impl Debug for ModeDescriptor
Sourceimpl Default for ModeDescriptor
impl Default for ModeDescriptor
Sourcefn default() -> ModeDescriptor
fn default() -> ModeDescriptor
Returns the “default value” for a type. Read more
Sourceimpl Message for ModeDescriptor
impl Message for ModeDescriptor
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ModeDescriptor
impl PartialEq for ModeDescriptor
impl StructuralPartialEq for ModeDescriptor