pub struct PolicyRegistryCapability {
pub register_policy: bool,
pub list_policies: bool,
pub list_changed: bool,
}Expand description
Policy registry capability advertised during Initialize.
Fields
register_policy: boollist_policies: boollist_changed: boolTrait Implementations
Sourceimpl Clone for PolicyRegistryCapability
impl Clone for PolicyRegistryCapability
Sourcefn clone(&self) -> PolicyRegistryCapability
fn clone(&self) -> PolicyRegistryCapability
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PolicyRegistryCapability
Sourceimpl Debug for PolicyRegistryCapability
impl Debug for PolicyRegistryCapability
Sourceimpl Default for PolicyRegistryCapability
impl Default for PolicyRegistryCapability
Sourcefn default() -> PolicyRegistryCapability
fn default() -> PolicyRegistryCapability
Returns the “default value” for a type. Read more
impl Eq for PolicyRegistryCapability
Sourceimpl Hash for PolicyRegistryCapability
impl Hash for PolicyRegistryCapability
Sourceimpl Message for PolicyRegistryCapability
impl Message for PolicyRegistryCapability
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PolicyRegistryCapability
impl PartialEq for PolicyRegistryCapability
Sourcefn eq(&self, other: &PolicyRegistryCapability) -> bool
fn eq(&self, other: &PolicyRegistryCapability) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PolicyRegistryCapability