pub struct TaskCompletePayload {
pub task_id: String,
pub assignee: String,
pub output: Vec<u8>,
pub summary: String,
}Fields
task_id: Stringassignee: Stringoutput: Vec<u8>summary: StringTrait Implementations
Sourceimpl Clone for TaskCompletePayload
impl Clone for TaskCompletePayload
Sourcefn clone(&self) -> TaskCompletePayload
fn clone(&self) -> TaskCompletePayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskCompletePayload
impl Debug for TaskCompletePayload
Sourceimpl Default for TaskCompletePayload
impl Default for TaskCompletePayload
Sourcefn default() -> TaskCompletePayload
fn default() -> TaskCompletePayload
Returns the “default value” for a type. Read more
impl Eq for TaskCompletePayload
Sourceimpl Hash for TaskCompletePayload
impl Hash for TaskCompletePayload
Sourceimpl Message for TaskCompletePayload
impl Message for TaskCompletePayload
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TaskCompletePayload
impl PartialEq for TaskCompletePayload
Sourcefn eq(&self, other: &TaskCompletePayload) -> bool
fn eq(&self, other: &TaskCompletePayload) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TaskCompletePayload