pub struct TaskRequestPayload {
pub task_id: String,
pub title: String,
pub instructions: String,
pub requested_assignee: String,
pub input: Vec<u8>,
pub deadline_unix_ms: i64,
}Fields
task_id: Stringtitle: Stringinstructions: Stringrequested_assignee: Stringinput: Vec<u8>deadline_unix_ms: i64Trait Implementations
Sourceimpl Clone for TaskRequestPayload
impl Clone for TaskRequestPayload
Sourcefn clone(&self) -> TaskRequestPayload
fn clone(&self) -> TaskRequestPayload
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskRequestPayload
impl Debug for TaskRequestPayload
Sourceimpl Default for TaskRequestPayload
impl Default for TaskRequestPayload
Sourcefn default() -> TaskRequestPayload
fn default() -> TaskRequestPayload
Returns the “default value” for a type. Read more
impl Eq for TaskRequestPayload
Sourceimpl Hash for TaskRequestPayload
impl Hash for TaskRequestPayload
Sourceimpl Message for TaskRequestPayload
impl Message for TaskRequestPayload
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TaskRequestPayload
impl PartialEq for TaskRequestPayload
impl StructuralPartialEq for TaskRequestPayload