pub struct PassthroughMode {
pub allowed_message_types: Vec<String>,
}Expand description
Generic extension mode handler for dynamically registered modes.
Accepts any message type listed in the mode descriptor. Commitment messages from the initiator resolve the session. All other messages are accepted and the payload is persisted as mode state.
Fields
allowed_message_types: Vec<String>Trait Implementations
Sourceimpl Mode for PassthroughMode
impl Mode for PassthroughMode
fn on_session_start( &self, _session: &Session, _env: &Envelope, ) -> Result<ModeResponse, MacpError>
fn on_message( &self, session: &Session, env: &Envelope, ) -> Result<ModeResponse, MacpError>
Authorize the sender for this message. Modes can override to customize
authorization (e.g., allowing orchestrator bypass for Commitment messages).